@@ -8,24 +8,30 @@
 class Options;
 class GPGHandler;
 
+#include <bobcat/tempstream>
+
 class Decryptor
 {
     Options const &d_options;
     GPGHandler &d_gpgHandler;
 
     std::unique_ptr<std::ofstream> d_fverbose;
+    std::unique_ptr<FBB::TempStream> d_pgpMessage;
+    std::unique_ptr<FBB::TempStream> d_decrypted;
+    std::string d_decryptedName;
 
     public:
         Decryptor(GPGHandler &gpgHandler);
                                                 // -----BEGIN PGP MESSAGE-----
                                                 // was just read by
-        void handlePGP(std::istream &in,         // Guncat::process
-                       std::ostream &out);
+        void process(std::istream &in);         // Guncat::process
 
     private:
+        void clearFiles() const;
+
         void setVerbose();
 
-        static void error(std::ostream &out, int ret, 
+        static void error(int ret, 
                           std::pair<unsigned, unsigned> const &range);
 };
 
