@@ -1,8 +1,9 @@
 #include "globals.ih"
 
-void  starred(std::ostream &out, std::string const &msg)
+void  starred(//std::ostream &out, 
+                std::string const &msg)
 {
-    out << '\n' <<
+    cout << '\n' <<
             setfill('*') << setw(msg.length()) << '*' << '\n' <<
             msg << '\n' <<
             setw(msg.length()) << '*' << '\n' << setfill(' ') <<
