@@ -12,9 +12,6 @@ void Guncat::programArguments()
         g_filename = arg[idx];
         ifstream in{ Exception::factory<ifstream>(g_filename) };
 
-        if (idx == 0)                           // set passphrase before
-            d_gpgHandler.checkPassphrase(in);   // processing the 1st files
-
         process(in);
     }
 }
