@@ -26,18 +26,11 @@ try
     
     Guncat guncat;
     guncat.run();                           // process all files
-}
-catch (int x)
-{
-    return x;
-}
-catch (exception const &exc)
-{
-    cerr << terminating << ": " << exc.what() << '\n';
-    return 1;
+
+    if (arg.option('d'))                    // dots were requested
+        cerr.put('\n');                     // then end the dots-line
 }
 catch (...)
 {
-    cerr << "Unexpected exception\n";
-    return 1;
+    return handle(current_exception());
 }
