@@ -6,6 +6,6 @@ bool PGPSection::nextLine()
     if (not ::nextline(d_in, d_line))
         return false;
 
-    d_tempStream << d_line << '\n';
+    d_pgpMessage << d_line << '\n';
     return true;
 }
