@@ -1,8 +1,10 @@
 //#define XERR
 #include "pgpsection.ih"
 
-PGPSection::PGPSection(istream &in)
+    // in: current input file, at 'PGP MESSAGE'
+PGPSection::PGPSection(istream &in, TempStream &pgpMessage)
 :
+    d_pgpMessage(pgpMessage),
     d_in(in),
     d_entryOffset(in.tellg()),
     d_offset(d_entryOffset)
