@@ -11,14 +11,14 @@ namespace
 {
     Arg::LongOption longOptions[] =
     {
+        Arg::LongOption("dots",             'd'),
         Arg::LongOption("gpg-command",      Arg::None),
-        Arg::LongOption("gpg-path",         Arg::Required),
         Arg::LongOption("gpg-option",       Arg::Required),
+        Arg::LongOption("gpg-path",         Arg::Required),
         Arg::LongOption("help",             'h'),
-        Arg::LongOption("less",             'l'),
         Arg::LongOption("no-errors",        Arg::None),
-        Arg::LongOption("passphrase",       'p'),
-        Arg::LongOption("pipe",             'P'),
+        Arg::LongOption("passphrase",       Arg::Required),
+        Arg::LongOption("pgp-messages",     'm'),
         Arg::LongOption("pgp-ranges",       'r'),
         Arg::LongOption("quoted-printable", 'q'), 
         Arg::LongOption("reduce-headers",   'R'), 
@@ -28,7 +28,6 @@ namespace
         Arg::LongOption("tty-OK",           't'),
         Arg::LongOption("verbose",          'V'),
         Arg::LongOption("version",          'v'),
-        Arg::LongOption("write",            'W'),
     };
 
     auto longEnd = longOptions + std::size(longOptions);
@@ -36,6 +35,6 @@ namespace
 
 Arg const &prepareArgs(int argc, char **argv)
 {
-    return Arg::initialize("hlpP:qRrsStT:vV:W:",
+    return Arg::initialize("dhm:qRrsStT:vV:",
                            longOptions, longEnd, argc, argv);
 }
